@@ -2,5 +2,5 @@ from cvxpy_leximin.objective import Leximax, Leximin
 from cvxpy_leximin.problem import LOGGER, Problem
 import pathlib
 
-PARENT = pathlib.Path(__file__).parent.parent
-__version__ = (PARENT / "VERSION").read_text().strip()
+HERE = pathlib.Path(__file__).parent
+__version__ = (HERE / "VERSION").read_text().strip()
